########
ROMMover
########

ROMMover will move the final chosen ROM files to a clean directory structure, optionally unzipping files along the way.

For more details on the ROMMover arguments, see the :doc:`config file documentation <../configs/config>`.

API
===

.. autoclass:: romsearch.ROMMover
    :no-index:
    :members:
    :undoc-members: